1. Snyder, John P., "Map Projections--A Working Manual", U.S. Geological Survey
    Professional Paper 1395 (Supersedes USGS Bulletin 1532),
    United States Government Printing Office, Washington D.C., 1987.
    Accessed: 2016-05-09.  https://pubs.er.usgs.gov/publication/pp1395
2. Snyder, John P. and Voxland, Philip M., "An Album of Map Projections",
    U.S. Geological Survey Professional Paper 1453 ,
    United State Government Printing Office, Washington D.C., 1989.
    Accessed: 2016-05-09.  https://pubs.er.usgs.gov/publication/pp1453
3. "Cartographic Projection Procedures for the UNIX Environment-
    A User's Manual" by Gerald I. Evenden,
    USGS Open File Report 90-284 and Release 4 Interim Reports (2003).
    Accessed: 2016-06-09.  http://www2.bren.ucsb.edu/~frew/ESM264/private/proj_manual.pdf
4. Snyder, John P., "Flattening the Earth -
    Two Thousand Years of Map Projections", Univ. Chicago Press, 1993
5. Wolfram Mathworld "Gnomonic Projection"
    http://mathworld.wolfram.com/GnomonicProjection.html
    Accessed: 12th November 2009
6. "New Equal-Area Map Projections for Noncircular Regions", John P. Snyder,
    The American Cartographer, Vol 15, No. 4, October 1988, pp. 341-355.
7. Snyder, John P., "Map Projections--A Working Manual", U.S. Geological
    Survey Professional Paper 1395 (Supersedes USGS Bulletin 1532), United
    State Government Printing Office, Washington D.C., 1987.
    Access date 2016-05-09.  https://pubs.er.usgs.gov/publication/pp1395
8. "Software Documentation for GCTP General Cartographic Transformation
    Package", U.S. Geological Survey National Mapping Division, May 1982.
9. Department of Land and Survey Technical Circular 1973/32
    http://www.linz.govt.nz/docs/miscellaneous/nz-map-definition.pdf
10. OSG Technical Report 4.1
    http://www.linz.govt.nz/docs/miscellaneous/nzmg.pdf
11. Formules et constantes pour le Calcul pour la
    projection cylindrique conforme à axe oblique et pour la transformation entre
    des systèmes de référence.
    http://www.swisstopo.admin.ch/internet/swisstopo/fr/home/topics/survey/sys/refsys/switzerland.parsysrelated1.31216.downloadList.77004.DownloadFile.tmp/swissprojectionfr.pdf
